@@ -25,20 +25,24 @@ class fe25519():
 
     @staticmethod
     def zero() -> fe25519:
-        return fe25519([0,0,0,0,0])
+        """Constant corresponding to the zero element."""
+        return fe25519([0, 0, 0, 0, 0])
 
     @staticmethod
     def one() -> fe25519:
-        return fe25519([1,0,0,0,0])
+        """Constant corresponding to the multiplicative identity element."""
+        return fe25519([1, 0, 0, 0, 0])
 
     def __init__(self: fe25519, ns: Sequence[int]):
         """Create a field element using a list of five 64-bit integers."""
         self.ns = ns
 
     def copy(self: fe25519):
-        return fe25519([n for n in self.ns])
+        """Create a copy of an element instance."""
+        return fe25519(list(self.ns))
 
     def reduce(self: fe25519) -> fe25519:
+        """Element reduction."""
         t = self.ns # 128-bit integers.
         mask = 2251799813685247
 
@@ -95,7 +99,7 @@ class fe25519():
         t[2] = (t[2] + (t[1] >> 51)) % TWO_TO_128
         t[1] &= mask
         t[3] = (t[3] + (t[2] >> 51)) % TWO_TO_128
-        t[2] &= mask;
+        t[2] &= mask
         t[4] = (t[4] + (t[3] >> 51)) % TWO_TO_128
         t[3] &= mask
         t[4] &= mask
@@ -103,18 +107,23 @@ class fe25519():
         return fe25519(t)
 
     def __add__(self: fe25519, other: fe25519) -> fe25519:
-        return fe25519([(m+n)%TWO_TO_64 for (m,n) in zip(self.ns, other.ns)])
+        """Addition of elements."""
+        return fe25519([(m+n)%TWO_TO_64 for (m, n) in zip(self.ns, other.ns)])
 
     def __neg__(self: fe25519) -> fe25519:
+        """Negation of an element."""
         return fe25519.zero() - self
 
     def cneg(self: fe25519, b: int) -> fe25519:
+        """Conditional negation of an element."""
         return self.copy().cmov(-self, b)
 
     def __abs__(self: fe25519) -> fe25519:
+        """Absolute value of an element."""
         return self.cneg(self.is_negative())
 
     def __sub__(self: fe25519, other: fe25519) -> fe25519:
+        """Subtraction of elements."""
         mask = 2251799813685247
 
         (h0, h1, h2, h3, h4) = other.ns
@@ -130,7 +139,7 @@ class fe25519():
         h0 = (h0 + 19 * (h4 >> 51)) % TWO_TO_64
         h4 &= mask
 
-        return fe25519([\
+        return fe25519([
             ((self.ns[0] + 4503599627370458) - h0) % TWO_TO_64,
             ((self.ns[1] + 4503599627370494) - h1) % TWO_TO_64,
             ((self.ns[2] + 4503599627370494) - h2) % TWO_TO_64,
@@ -139,6 +148,7 @@ class fe25519():
         ])
 
     def __mul__(self: fe25519, other: fe25519) -> fe25519:
+        """Multiplication of elements."""
         mask = 2251799813685247 # 64-bit integer.
         (f, g) = (self.ns, other.ns) # 64-bit integers.
         r = [None, None, None, None, None] # 128-bit integers.
@@ -176,6 +186,7 @@ class fe25519():
         return fe25519(r0)
 
     def sq(self: fe25519) -> fe25519:
+        """Squaring of an element."""
         mask = 2251799813685247 # 64-bit integer.
         f = self.ns # 64-bit integers.
         r = [None, None, None, None, None] # 128-bit integers.
@@ -218,6 +229,7 @@ class fe25519():
         return fe25519(r0)
 
     def sq2(self: fe25519) -> fe25519:
+        """Repeated squaring of an element."""
         mask = 2251799813685247
         f = self.ns # 64-bit integers.
         r = [None, None, None, None, None] # 128-bit integers.
@@ -247,12 +259,12 @@ class fe25519():
         r[4] <<= 1
 
         r0[0] = (r[0] % TWO_TO_64) & mask
-        carry  = r[0] >> 51
+        carry = r[0] >> 51
         r[1] = (r[1] + carry) % TWO_TO_128
         r0[1] = (r[1] % TWO_TO_64) & mask
-        carry  = r[1] >> 51
+        carry = r[1] >> 51
         r[2] = (r[2] + carry) % TWO_TO_128
-        
+
         r0[2] = (r[2] % TWO_TO_64) & mask
         carry = r[2] >> 51
         r[3] = (r[3] + carry) % TWO_TO_128
@@ -263,7 +275,7 @@ class fe25519():
         carry = r[4] >> 51
         r0[0] = (r0[0] + 19*carry) % TWO_TO_64
         carry = r0[0] >> 51
-        r0[0] &= mask 
+        r0[0] &= mask
         r0[1] = (r0[1] + (carry % TWO_TO_64)) % TWO_TO_64
         carry = r0[1] >> 51
         r0[1] &= mask
@@ -272,13 +284,17 @@ class fe25519():
         return fe25519(r0)
 
     def __pow__(self: fe25519, e: int) -> fe25519:
+        """Synonym for squaring and inversion."""
         if e == 2: # Squaring.
             return self.sq()
+        if e == -1: # Inversion.
+            return self.invert()
 
         # Supplied exponent is not supported.
         return None
 
     def pow22523(self: fe25519) -> fe25519:
+        """Exponentiation (special fixed exponent)."""
         z = self.copy()
         t0 = z.sq()
         t1 = t0.sq()
@@ -288,31 +304,31 @@ class fe25519():
         t0 = t0.sq()
         t0 = t1 * t0
         t1 = t0.sq()
-        for i in range(1,5):
+        for _ in range(1, 5):
             t1 = t1.sq()
         t0 = t1 * t0
         t1 = t0.sq()
-        for i in range(1,10):
+        for _ in range(1, 10):
             t1 = t1.sq()
         t1 = t1 * t0
         t2 = t1.sq()
-        for i in range(1,20):
+        for _ in range(1, 20):
             t2 = t2.sq()
         t1 = t2 * t1
         t1 = t1.sq()
-        for i in range(1,10):
+        for _ in range(1, 10):
             t1 = t1.sq()
         t0 = t1 * t0
         t1 = t0.sq()
-        for i in range(1,50):
+        for _ in range(1, 50):
             t1 = t1.sq()
         t1 = t1 * t0
         t2 = t1.sq()
-        for i in range(1,100):
+        for _ in range(1, 100):
             t2 = t2.sq()
         t1 = t2 * t1
         t1 = t1.sq()
-        for i in range(1,50):
+        for _ in range(1, 50):
             t1 = t1.sq()
         t0 = t1 * t0
         t0 = t0.sq()
@@ -320,6 +336,7 @@ class fe25519():
         return t0 * z
 
     def invert(self: fe25519) -> fe25519:
+        """Inversion of an element."""
         z = self.copy()
         t0 = z.sq()
         t1 = t0.sq()
@@ -329,39 +346,40 @@ class fe25519():
         t2 = t0.sq()
         t1 = t1 * t2
         t2 = t1.sq()
-        for i in range(1,5):
+        for _ in range(1, 5):
             t2 = t2.sq()
         t1 = t2 * t1
         t2 = t1.sq()
-        for i in range(1,10):
+        for _ in range(1, 10):
             t2 = t2.sq()
         t2 = t2 * t1
         t3 = t2.sq()
-        for i in range(1,20):
+        for _ in range(1, 20):
             t3 = t3.sq()
         t2 = t3 * t2
         t2 = t2.sq()
-        for i in range(1,10):
+        for _ in range(1, 10):
             t2 = t2.sq()
         t1 = t2 * t1
         t2 = t1.sq()
-        for i in range(1,50):
+        for _ in range(1, 50):
             t2 = t2.sq()
         t2 = t2 * t1
         t3 = t2.sq()
-        for i in range(1,100):
+        for _ in range(1, 100):
             t3 = t3.sq()
         t2 = t3 * t2
         t2 = t2.sq()
-        for i in range(1,50):
+        for _ in range(1, 50):
             t2 = t2.sq()
         t1 = t2 * t1
         t1 = t1.sq()
-        for i in range(1,5):
+        for _ in range(1, 5):
             t1 = t1.sq()
         return t1 * t0
 
     def sqrt_ratio_m1_ristretto255(self: fe25519, v: fe25519) -> Tuple[fe25519, int]:
+        """Specialized root operation."""
         u = self
 
         v3 = v.sq()
@@ -391,69 +409,75 @@ class fe25519():
         return (x, has_m_root | has_p_root)
 
     def chi25519(self: fe25519) -> fe25519:
+        """Specialized root function (for elligator)."""
         t0 = self.sq()
         t1 = t0 * self
-        t0 = t1.sq() 
+        t0 = t1.sq()
         t2 = t0.sq()
         t2 = t2.sq()
         t2 = t2 * t0
         t1 = t2 * self
         t2 = t1.sq()
 
-        for i in range(1,5):
+        for _ in range(1, 5):
             t2 = t2.sq()
         t1 = t2 * t1
         t2 = t1.sq()
-        for i in range(1,10):
+        for _ in range(1, 10):
             t2 = t2.sq()
         t2 = t2 * t1
         t3 = t2.sq()
-        for i in range(1,20):
+        for _ in range(1, 20):
             t3 = t3.sq()
         t2 = t3 * t2
         t2 = t2.sq()
-        for i in range(1,10):
+        for _ in range(1, 10):
             t2 = t2.sq()
         t1 = t2 * t1
         t2 = t1.sq()
-        for i in range(1,50):
+        for _ in range(1, 50):
             t2 = t2.sq()
         t2 = t2 * t1
         t3 = t2.sq()
-        for i in range(1,100):
+        for _ in range(1, 100):
             t3 = t3.sq()
         t2 = t3 * t2
         t2 = t2.sq()
-        for i in range(1,50):
+        for _ in range(1, 50):
             t2 = t2.sq()
         t1 = t2 * t1
         t1 = t1.sq()
-        for i in range(1,4):
+        for _ in range(1, 4):
             t1 = t1.sq()
 
         return t1 * t0
 
     def __eq__(self: fe25519, other: fe25519) -> bool:
+        """Equality of elements."""
         return self.ns == other.ns
 
     def is_zero(self: fe25519) -> int:
+        """Determine whether an element is zero."""
         bs = self.to_bytes()
         d = 0
-        for i in range(len(bs)):
-            d |= bs[i]
+        for b in bs:
+            d |= b
         return 1 & ((d - 1) >> 8)
 
     def is_negative(self: fe25519) -> int:
+        """Determine whether an element is negative."""
         bs = self.to_bytes()
         return bs[0] & 1
 
     def cmov(self: fe25519, g: fe25519, b: int) -> fe25519:
+        """Conditional selection of an element based on boolean integer."""
         mask = TWO_TO_64 - b
         pairs = zip(self.ns, g.ns)
-        return fe25519([fi ^ ((fi ^ gi) & mask) for (fi,gi) in pairs])
+        return fe25519([fi ^ ((fi ^ gi) & mask) for (fi, gi) in pairs])
 
     @staticmethod
     def from_bytes(bs: bytes) -> fe25519:
+        """Assembly of an element instance from its byte representation."""
         mask = 2251799813685247
 
         def load64_le(bs):
@@ -467,7 +491,7 @@ class fe25519():
             w |= bs[7] << 56
             return w
 
-        return fe25519([\
+        return fe25519([
             (load64_le(bs[0:8])) & mask,
             (load64_le(bs[6:14]) >> 3) & mask,
             (load64_le(bs[12:20]) >> 6) & mask,
@@ -476,6 +500,7 @@ class fe25519():
         ])
 
     def to_bytes(self: fe25519) -> bytes:
+        """Byte representation of an element."""
         t = self.reduce().ns
 
         t0 = t[0] | ((t[1] << 51) % TWO_TO_64)
@@ -491,17 +516,27 @@ class fe25519():
         return bs
 
     def __str__(self: fe25519) -> str:
+        """String representation of an element."""
         return 'fe25519(' + str(self.ns) + ')'
 
     def __repr__(self: fe25519) -> str:
-        return str(self)
+        """String representation of an element."""
+        return str(self) # pragma: no cover
 
 # Precomputed static constants.
-fe25519.d = fe25519([929955233495203, 466365720129213, 1662059464998953, 2033849074728123, 1442794654840575])
-fe25519.d2 = fe25519([1859910466990425, 932731440258426, 1072319116312658, 1815898335770999, 633789495995903])
-fe25519.sqrtm1 = fe25519([1718705420411056, 234908883556509, 2233514472574048, 2117202627021982, 765476049583133])
-fe25519.invsqrtamd = fe25519([278908739862762, 821645201101625, 8113234426968, 1777959178193151, 2118520810568447])
+fe25519.d = fe25519([
+    929955233495203, 466365720129213, 1662059464998953, 2033849074728123, 1442794654840575
+])
+fe25519.d2 = fe25519([
+    1859910466990425, 932731440258426, 1072319116312658, 1815898335770999, 633789495995903
+])
+fe25519.sqrtm1 = fe25519([
+    1718705420411056, 234908883556509, 2233514472574048, 2117202627021982, 765476049583133
+])
+fe25519.invsqrtamd = fe25519([
+    278908739862762, 821645201101625, 8113234426968, 1777959178193151, 2118520810568447
+])
 fe25519.curve25519_A = fe25519([486662, 0, 0, 0, 0])
 
 if __name__ == "__main__":
-    doctest.testmod()
+    doctest.testmod() # pragma: no cover
